==> haskell-aeson-2.1.2.1-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4
key:                  aeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  0c9444cf60e67249a3a8edf621b7823d
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-HUj8Ou2Jrr19darX8iyQt4
depends:
    OneTuple-0.4.2-H2hq3WX7vAYH5Mde32s1b7
    QuickCheck-2.14.3-1roXk93057vCM76NaUaTTz
    attoparsec-0.14.4-BuoYNqKkZ0cK5gzfHXNsJW base-4.17.2.1
    base-compat-batteries-0.12.3-7BiHnBCEVHaGSHMgy6EnRY
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.4-LcGqGMKSqJWL0Y2W5B7FdX deepseq-1.4.8.0
    dlist-1.0-JoSBAcTbq69IOdBJgaKPCB exceptions-0.10.5
    generically-0.1.1-4zWFCUTSqVQCJe2o7wRevt ghc-prim-0.9.1
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    indexed-traversable-0.1.4-2T176InstcMqAaY6WCojl
    primitive-0.9.1.0-8D3oUlMRcY7326zIYb2IW2
    scientific-0.3.8.0-3JrZTDh3ZlGFN4TNaQrQZi
    semialign-1.3.1-78bX6Kuis2uA1ByKwlbsqr
    strict-0.5-Jgky6Rzyq2z6l0O73M6yfd
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 text-short-0.1.6-G05xAmjvzxF6KbLM99PA0Y
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    these-1.2.1-8N2G6PeN9eQ6G2ecL7DSJd time-1.12.2
    time-compat-1.9.6.1-IJTFIVvvvxiKnwU2IMshFs
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP
    uuid-types-1.0.6-7nA6AJWpVRaLG82S0awfi3
    vector-0.13.2.0-GDtmlcfK9QZ7E5AlTQVnIi
    witherable-0.4.2-4na2W715HuZLlMQIFp1gaK

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-2.1.2.1-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson
version:              2.1.2.1
visibility:           public
id:                   aeson-2.1.2.1-7goQjQKasWuq7oOasot83
key:                  aeson-2.1.2.1-7goQjQKasWuq7oOasot83
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.

    To get started, see the documentation for the @Data.Aeson@ module
    below.

    (A note on naming: in Greek mythology, Aeson was the father of Jason.)

category:             Text, Web, JSON
abi:                  ee157154e5f1e1183dc27f47d0a16f53
exposed:              True
exposed-modules:
    Data.Aeson Data.Aeson.Decoding Data.Aeson.Decoding.ByteString
    Data.Aeson.Decoding.ByteString.Lazy Data.Aeson.Decoding.Tokens
    Data.Aeson.Encoding Data.Aeson.Encoding.Internal
    Data.Aeson.Internal Data.Aeson.Internal.Time Data.Aeson.Key
    Data.Aeson.KeyMap Data.Aeson.Parser Data.Aeson.Parser.Internal
    Data.Aeson.QQ.Simple Data.Aeson.TH Data.Aeson.Text Data.Aeson.Types

hidden-modules:
    Data.Aeson.Decoding.Internal Data.Aeson.Encoding.Builder
    Data.Aeson.Internal.ByteString Data.Aeson.Internal.Functions
    Data.Aeson.Internal.Integer Data.Aeson.Internal.Text
    Data.Aeson.Internal.TH Data.Aeson.Internal.Word8
    Data.Aeson.Parser.Time Data.Aeson.Parser.Unescape
    Data.Aeson.Types.Class Data.Aeson.Types.FromJSON
    Data.Aeson.Types.Generic Data.Aeson.Types.Internal
    Data.Aeson.Types.ToJSON Data.Attoparsec.Time
    Data.Attoparsec.Time.Internal Data.Aeson.Parser.UnescapePure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-2.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson
hs-libraries:         HSaeson-2.1.2.1-7goQjQKasWuq7oOasot83
depends:
    OneTuple-0.4.2-H2hq3WX7vAYH5Mde32s1b7
    QuickCheck-2.14.3-76HC5XzyauqDQFZ8BHcZeC
    attoparsec-0.14.4-fEKSJrOU814GdIIzzkkyx base-4.17.2.1
    base-compat-batteries-0.12.3-6pWcl9IFv3CCeV7vXcq59
    bytestring-0.11.5.3 containers-0.6.7
    data-fix-0.3.4-JRUuGn1EtkV9Aimb3ju7o7 deepseq-1.4.8.0
    dlist-1.0-3IsW2ghxYJNLBlqCManDLX exceptions-0.10.5
    generically-0.1.1-9vkE5tgE0hhFrqsF6XlkQY ghc-prim-0.9.1
    hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb
    indexed-traversable-0.1.4-1jVJAb9Ott1EiIUD50SH50
    primitive-0.9.1.0-BgUaaPOPm1nFHgpR53Jjhz
    scientific-0.3.8.0-HfCn6ildxXk6zQelWj77aL
    semialign-1.3.1-AVlZaRFGQJiAKkDFIoiwk3
    strict-0.5-36ewJDkZRDI4NWxhB7d4cc
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2 text-short-0.1.6-2R6TTZgmlE2D0QDVS4Qfvx
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    these-1.2.1-Kw5oHqb1vv5A6eo0njmZYD time-1.12.2
    time-compat-1.9.6.1-2ls2GASKJ6z1bA0uZKKYYa
    unordered-containers-0.2.20-5ChD9TF8iAH5uLARI0QLMz
    uuid-types-1.0.6-EhGDdLa78kyAYHENLtQBIX
    vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh
    witherable-0.4.2-KtuRnnLik4U8TkP2gzhD6n

haddock-interfaces:   /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html:         /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
